@@ -2,9 +2,13 @@ require_relative 'mnist'
 
 module Datasets
   class FashionMNIST < MNIST
-    BASE_URL = "http://fashion-mnist.s3-website.eu-central-1.amazonaws.com/"
-
     private
+    def base_urls
+      [
+        "http://fashion-mnist.s3-website.eu-central-1.amazonaws.com/",
+      ]
+    end
+
     def dataset_name
       "Fashion-MNIST"
     end
